@@ -59,8 +59,10 @@ DEFAULT_ARTIFICIAL_END_ACTIVITY = "■"
 DEFAULT_BUSINESS_HOURS_WORKCALENDAR = None
 
 SHOW_EVENT_LOG_DEPRECATION = True
+TRIGGERED_DT_PARSING_WARNING = False
 
 DEFAULT_BGCOLOR = "white"
+DEFAULT_FORMAT_GVIZ_VIEW = "png"
 
 ENABLE_MULTIPROCESSING_DEFAULT = False
 
