@@ -15,6 +15,8 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 import shutil
+import os
+from pm4py.visualization.common import dot_util
 
 
 def save(gviz, output_file_path):
@@ -28,5 +30,8 @@ def save(gviz, output_file_path):
     output_file_path
         Path where the GraphViz output should be saved
     """
+    format = os.path.splitext(output_file_path)[1][1:].lower()
+    is_dot_installed = dot_util.check_dot_installed()
+
     render = gviz.render(cleanup=True)
     shutil.copyfile(render, output_file_path)
